==> ejc-ztpcdata-api-3.0.0-20251022.015950-111-sources.jar: com/ejianc/ztpcdata/hystrix/ExternalHystrix.java <==
package com.ejianc.ztpcdata.hystrix;

import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.share.vo.SupplierVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.ztpcdata.api.IExternalApi;
import com.ejianc.ztpcdata.vo.*;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;
import java.util.Map;

@Component
public class ExternalHystrix implements IExternalApi {

    private Throwable cause;

    public void setCause(Throwable cause) {
        this.cause = cause;
    }
    @Override
    public CommonResponse<List<ButtonVO>> getButton(Map<String, Object> params) {
        return CommonResponse.error("网络问题，查询失败。");
    }

    @Override
    public CommonResponse<Integer> getButtonCount() {
        return CommonResponse.error("网络问题，查询失败。");
    }

    @Override
    public CommonResponse<List<AttachmentVO>> getFileId(Map<String, Object> params) {
        return CommonResponse.error("网络问题，查询失败。");
    }

    @Override
    public CommonResponse<List<ActRuTaskVO>> getByBizKey(String businessKey) {
        return CommonResponse.error("网络问题，查询失败。");
    }

    @Override
    public CommonResponse<List<IdeModuleVO>> getMyPageInfo(String appId, String code) {
        return CommonResponse.error("网络问题，查询失败。");
    }

    @Override
    public CommonResponse<List<Long>> getOrgIdByOrgCode(String orgCode) {
        return CommonResponse.error("网络问题，查询失败。");
    }

    @Override
    public CommonResponse<List<Map<String, Object>>> getMapProjLocal() {
        return CommonResponse.error("网络问题，查询失败。");
    }

    @Override
    public CommonResponse<List<Map<String, Object>>> queryAllDept() {
        return CommonResponse.error("网络问题，查询失败。");
    }

    @Override
    public CommonResponse<List<Map<String, Object>>> queryAllDeptCondition(String orgId) {
        return CommonResponse.error("网络问题，查询失败。");
    }

    @Override
    public CommonResponse<List<Map<String, Object>>> getMapAllEmployee() {
        return CommonResponse.error("网络问题，查询失败。");
    }

    @Override
    public CommonResponse<List<Map<String, Object>>> getAttachmentBySourceIdAndSourceType(Long sourceId,String sourceType) {
        return CommonResponse.error("网络问题，查询失败。");
    }

    @Override
    public CommonResponse<List<OrgVO>> getOrgList(Integer orgType, Integer projectState, Long parentOrgId) {
        return CommonResponse.error("网络问题，查询失败。");
    }

    @Override
    public CommonResponse<List<EmployeeVO>> getEmployeeByName(List<String> names) {
        return CommonResponse.error("网络问题，查询失败。");
    }

    @Override
    public CommonResponse<List<SupplierVO>> querySupplierByName(@RequestParam("name")String name){
        return CommonResponse.error("网络问题，查询失败。");
    }

    @Override
    public CommonResponse<List<Map<String, Object>>> querySupplierByIds(String ids) {
        if (cause != null) {
            String errorMessage = "降级原因: " + cause.getMessage();
            return CommonResponse.error("查询失败:"+errorMessage);
        }
        return CommonResponse.error("查询失败");
    }
}

==> ejc-ztpcdata-api-3.0.0-20251023.024227-115-sources.jar: com/ejianc/ztpcdata/hystrix/ExternalHystrix.java <==
package com.ejianc.ztpcdata.hystrix;

import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.share.vo.SupplierVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.ztpcdata.api.IExternalApi;
import com.ejianc.ztpcdata.vo.*;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;
import java.util.Map;

@Component
public class ExternalHystrix implements IExternalApi {

    private Throwable cause;

    public void setCause(Throwable cause) {
        this.cause = cause;
    }
    @Override
    public CommonResponse<List<ButtonVO>> getButton(Map<String, Object> params) {
        return CommonResponse.error("网络问题，查询失败。");
    }

    @Override
    public CommonResponse<Integer> getButtonCount() {
        return CommonResponse.error("网络问题，查询失败。");
    }

    @Override
    public CommonResponse<List<AttachmentVO>> getFileId(Map<String, Object> params) {
        return CommonResponse.error("网络问题，查询失败。");
    }

    @Override
    public CommonResponse<List<ActRuTaskVO>> getByBizKey(String businessKey) {
        return CommonResponse.error("网络问题，查询失败。");
    }

    @Override
    public CommonResponse<List<IdeModuleVO>> getMyPageInfo(String appId, String code) {
        return CommonResponse.error("网络问题，查询失败。");
    }

    @Override
    public CommonResponse<List<Long>> getOrgIdByOrgCode(String orgCode) {
        return CommonResponse.error("网络问题，查询失败。");
    }

    @Override
    public CommonResponse<List<Map<String, Object>>> getMapProjLocal() {
        return CommonResponse.error("网络问题，查询失败。");
    }

    @Override
    public CommonResponse<List<Map<String, Object>>> queryAllDept() {
        return CommonResponse.error("网络问题，查询失败。");
    }

    @Override
    public CommonResponse<List<Map<String, Object>>> queryAllDeptCondition(String orgId) {
        return CommonResponse.error("网络问题，查询失败。");
    }

    @Override
    public CommonResponse<List<Map<String, Object>>> getMapAllEmployee() {
        return CommonResponse.error("网络问题，查询失败。");
    }

    @Override
    public CommonResponse<List<Map<String, Object>>> getAttachmentBySourceIdAndSourceType(Long sourceId,String sourceType) {
        return CommonResponse.error("网络问题，查询失败。");
    }

    @Override
    public CommonResponse<List<OrgVO>> getOrgList(Integer orgType, Integer projectState, Long parentOrgId) {
        return CommonResponse.error("网络问题，查询失败。");
    }

    @Override
    public CommonResponse<List<EmployeeVO>> getEmployeeByName(List<String> names) {
        return CommonResponse.error("网络问题，查询失败。");
    }

    @Override
    public CommonResponse<List<Map<String, Object>>> querySupplierByName(@RequestParam("name")String name){
        return CommonResponse.error("网络问题，查询失败。");
    }

    @Override
    public CommonResponse<List<Map<String, Object>>> querySupplierByIds(String ids) {
        if (cause != null) {
            String errorMessage = "降级原因: " + cause.getMessage();
            return CommonResponse.error("查询失败:"+errorMessage);
        }
        return CommonResponse.error("查询失败");
    }
}
